@@ -54,7 +54,8 @@ headers and provide form."
   (unless featurename
     (setq featurename "test"))
   (with-temp-buffer
-    (emacs-lisp-mode)
+    (let ((delay-mode-hooks t))
+      (emacs-lisp-mode))
     (insert (or header (format ";;; %s.el --- A test\n" featurename)))
     (insert (or version ";; Package-Version: 0\n"))
     (insert (or url ";; URL: https://package-lint.test/p?q#f\n"))
@@ -153,7 +154,7 @@ headers and provide form."
 (ert-deftest package-lint-test-warn-no-standard-keyword ()
   (should
    (equal
-    '((6 3 warning "You should include standard keywords: see the variable `finder-known-keywords'."))
+    '((6 13 warning "You should include standard keywords: see the variable `finder-known-keywords'."))
     (package-lint-test--run ";; Keywords: foo"))))
 
 (ert-deftest package-lint-test-no-warning-if-at-least-one-standard-keyword ()
@@ -342,11 +343,11 @@ Alternatively, depend on (emacs \"24.3\") or greater, in which cl-lib is bundled
 (ert-deftest package-lint-test-warning-cl-lib-not-needed ()
   (should
    (member
-    '(6 52 warning "An explicit dependency on cl-lib <= 1.0 is not needed on Emacs >= 24.3.")
+    '(6 21 warning "An explicit dependency on cl-lib <= 1.0 is not needed on Emacs >= 24.3.")
     (package-lint-test--run ";; Package-Requires: ((emacs \"25.1\") (cl-lib \"1.0\"))")))
   (should
    (member
-    '(6 52 warning "An explicit dependency on cl-lib <= 1.0 is not needed on Emacs >= 24.3.")
+    '(6 21 warning "An explicit dependency on cl-lib <= 1.0 is not needed on Emacs >= 24.3.")
     (package-lint-test--run ";; Package-Requires: ((emacs \"24.3\") (cl-lib \"0.5\"))"))))
 
 (ert-deftest package-lint-test-warning-cl ()
@@ -489,6 +490,22 @@ Alternatively, depend on (emacs \"24.3\") or greater, in which cl-lib is bundled
      ";; Package-Requires: ((compat \"29\"))
 \(with-suppressed-warnings (foo))"))))
 
+(ert-deftest package-lint-test-accepts-compat-call ()
+  (should
+   (equal
+    '()
+    (package-lint-test--run
+     ";; Package-Requires: ((compat \"29\"))
+\(compat-call 'foo)"))))
+
+(ert-deftest package-lint-test-accepts-compat-require ()
+  (should
+   (equal
+    '()
+    (package-lint-test--run
+     ";; Package-Requires: ((compat \"29\"))
+\(require 'compat)"))))
+
 (ert-deftest package-lint-test-error-nonstandard-symbol-separator ()
   (should
    (equal
@@ -515,6 +532,10 @@ Alternatively, depend on (emacs \"24.3\") or greater, in which cl-lib is bundled
    (equal
     '((6 0 error "\"foo\" doesn't start with package's prefix \"test\"."))
     (package-lint-test--run "(defun foo ())")))
+  (should
+   (equal
+    '((6 0 error "\"testify\" doesn't start with package's prefix \"test\"."))
+    (package-lint-test--run "(defun testify ())")))
   (should
    (equal
     '((6 0 error "\"global-testfoo-mode\" doesn't start with package's prefix \"test\"."))
